@@ -66,7 +66,12 @@ def main():
         if args.cookies_from_browser:
             browser, _, profile = args.cookies_from_browser.partition(":")
             browser, _, keyring = browser.partition("+")
-            config.set((), "cookies", (browser, profile, keyring))
+            if profile.startswith(":"):
+                container = profile[1:]
+                profile = None
+            else:
+                profile, _, container = profile.partition("::")
+            config.set((), "cookies", (browser, profile, keyring, container))
         for opts in args.options:
             config.set(*opts)
 
@@ -118,25 +123,15 @@ def main():
             config.set(("output",), "mode", "null")
         elif args.loglevel <= logging.DEBUG:
             import platform
-            import subprocess
-            import os.path
             import requests
 
             extra = ""
             if getattr(sys, "frozen", False):
                 extra = " - Executable"
             else:
-                try:
-                    out, err = subprocess.Popen(
-                        ("git", "rev-parse", "--short", "HEAD"),
-                        stdout=subprocess.PIPE,
-                        stderr=subprocess.PIPE,
-                        cwd=os.path.dirname(os.path.abspath(__file__)),
-                    ).communicate()
-                    if out and not err:
-                        extra = " - Git HEAD: " + out.decode().rstrip()
-                except (OSError, subprocess.SubprocessError):
-                    pass
+                git_head = util.git_head()
+                if git_head:
+                    extra = " - Git HEAD: " + git_head
 
             log.debug("Version %s%s", __version__, extra)
             log.debug("Python %s - %s",
@@ -148,6 +143,8 @@ def main():
             except AttributeError:
                 pass
 
+            log.debug("Configuration Files %s", config._files)
+
         if args.list_modules:
             extractor.modules.append("")
             sys.stdout.write("\n".join(extractor.modules))
@@ -201,7 +198,8 @@ def main():
                             if sys.stdin:
                                 urls += util.parse_inputfile(sys.stdin, log)
                             else:
-                                log.warning("input file: stdin is not readable")
+                                log.warning(
+                                    "input file: stdin is not readable")
                         else:
                             with open(inputfile, encoding="utf-8") as file:
                                 urls += util.parse_inputfile(file, log)
@@ -235,7 +233,7 @@ def main():
                 except exception.TerminateExtraction:
                     pass
                 except exception.NoExtractorError:
-                    log.error("No suitable extractor found for '%s'", url)
+                    log.error("Unsupported URL '%s'", url)
                     retval |= 64
             return retval
 
