@@ -39,6 +39,7 @@ modules = [
     "fallenangels",
     "fanbox",
     "fantia",
+    "fapello",
     "fapachi",
     "flickr",
     "furaffinity",
@@ -74,13 +75,12 @@ modules = [
     "keenspot",
     "kemonoparty",
     "khinsider",
-    "kissgoddess",
-    "kohlchan",
     "komikcast",
     "lightroom",
     "lineblog",
     "livedoor",
     "luscious",
+    "lynxchan",
     "mangadex",
     "mangafox",
     "mangahere",
@@ -131,6 +131,7 @@ modules = [
     "slickpic",
     "slideshare",
     "smugmug",
+    "soundgasm",
     "speakerdeck",
     "subscribestar",
     "tapas",
@@ -151,6 +152,7 @@ modules = [
     "wallpapercave",
     "warosu",
     "weasyl",
+    "webmshare",
     "webtoons",
     "weibo",
     "wikiart",
