@@ -117,7 +117,7 @@ class SmugmugImageExtractor(SmugmugExtractor):
         # video
         ("https://tstravels.smugmug.com/Dailies/Daily-Dose-2015/i-39JFNzB", {
             "url": "04d0ab1ff829ca7d78f5acb5548953df08e9a5ee",
-            "keyword": "4cef98133ace511adc874c9d9abac5817ba0d856",
+            "keyword": "2b545184592c282b365fcbb7df6ca7952b8a3173",
         }),
     )
 
@@ -209,9 +209,9 @@ class SmugmugPathExtractor(SmugmugExtractor):
 class SmugmugAPI(oauth.OAuth1API):
     """Minimal interface for the smugmug API v2"""
     API_DOMAIN = "api.smugmug.com"
-    API_KEY = "DFqxg4jf7GrtsQ5PnbNB8899zKfnDrdK"
-    API_SECRET = ("fknV35p9r9BwZC4XbTzvCXpcSJRdD83S"
-                  "9nMFQm25ndGBzNPnwRDbRnnVBvqt4xTq")
+    API_KEY = "RCVHDGjcbc4Fhzq4qzqLdZmvwmwB6LM2"
+    API_SECRET = ("jGrdndvJqhTx8XSNs7TFTSSthhZHq92d"
+                  "dMpbpDpkDVNM7TDgnvLFMtfB5Mg5kH73")
     HEADERS = {"Accept": "application/json"}
 
     def album(self, album_id, expands=None):
