@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2017-2021 Mike Fährmann
+# Copyright 2017-2022 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -124,6 +124,11 @@ def build_parser():
         dest="source-address", metavar="IP", action=ConfigAction,
         help="Client-side IP address to bind to",
     )
+    general.add_argument(
+        "--user-agent",
+        dest="user-agent", metavar="UA", action=ConfigAction,
+        help="User-Agent request header",
+    )
     general.add_argument(
         "--clear-cache",
         dest="clear_cache", metavar="MODULE",
@@ -137,10 +142,12 @@ def build_parser():
     )
     general.add_argument(
         "--cookies-from-browser",
-        dest="cookies_from_browser", metavar="BROWSER[+KEYRING][:PROFILE]",
+        dest="cookies_from_browser",
+        metavar="BROWSER[+KEYRING][:PROFILE][::CONTAINER]",
         help=("Name of the browser to load cookies from, "
-              "with optional keyring name prefixed with '+' and "
-              "profile prefixed with ':'"),
+              "with optional keyring name prefixed with '+', "
+              "profile prefixed with ':', and "
+              "container prefixed with '::' ('none' for no container)"),
     )
 
     output = parser.add_argument_group("Output Options")
@@ -262,6 +269,11 @@ def build_parser():
         dest="filesize-max", metavar="SIZE", action=ConfigAction,
         help="Do not download files larger than SIZE (e.g. 500k or 2.5M)",
     )
+    downloader.add_argument(
+        "--chunk-size",
+        dest="chunk-size", metavar="SIZE", action=ConfigAction,
+        help="Size of in-memory data chunks (default: 32k)",
+    )
     downloader.add_argument(
         "--no-part",
         dest="part", nargs=0, action=ConfigConstAction, const=False,
@@ -283,6 +295,11 @@ def build_parser():
         dest="download", nargs=0, action=ConfigConstAction, const=False,
         help=("Do not download any files")
     )
+    downloader.add_argument(
+        "--no-postprocessors",
+        dest="postprocess", nargs=0, action=ConfigConstAction, const=False,
+        help=("Do not run any post processors")
+    )
     downloader.add_argument(
         "--no-check-certificate",
         dest="verify", nargs=0, action=ConfigConstAction, const=False,
